@@ -22,6 +22,9 @@ class InstalacaoNaoFinalizada(Exception):
 class Parametros(object):
     def __init__(self, meio_pagamento, **argumentos_da_instancia):
         self.meio_pagamento = meio_pagamento
+        self.monta_paramentros(**argumentos_da_instancia)
+
+    def monta_paramentros(self, **argumentos_da_instancia):
         try:
             parametros = settings.MODULO_PARAMETROS_INSTALACAO
         except AttributeError:
@@ -37,9 +40,10 @@ class Parametros(object):
         except KeyError:
             raise ParametroInstalacaoInvalido(u"A classe dos parâmetros não foi encontrada nas configurações. Você esqueceu de inclui-la em pagador.settings.MODULO_PARAMETROS_INSTALACAO?")
         try:
-            instancia = None
             if parametros["tipo_classe"] == "Django":
                 instancia = classe.objects.get(**argumentos_da_instancia)
+            else:
+                instancia = classe()
         except KeyError:
             raise ParametroInstalacaoInvalido(u"O tipo da classe dos parâmetros não foi encontrado nas configurações. Você esqueceu de inclui-lo em pagador.settings.MODULO_PARAMETROS_INSTALACAO?")
         try:
@@ -49,10 +53,16 @@ class Parametros(object):
                     conteudo = getattr(conteudo, atributo)
             except AttributeError:
                 raise ParametroInstalacaoInvalido(u"O atributo {} definido em pagador.settings.MODULO_PARAMETROS_INSTALACAO não é membro do classe {}.".format(parametros["atributo"], parametros["classe"]))
-            #FIXME: só funciona se o parâmetro for um dicionário.
-            for chave in self.chaves:
-                if parametros["tipo_atributo"] == "dict":
-                    setattr(self, chave, conteudo[meio_pagamento][chave])
+            if conteudo is None:
+                self.monta_paramentros(id=1)
+            else:
+                #FIXME: só funciona se o parâmetro for um dicionário.
+                for chave in self.chaves:
+                    if parametros["tipo_atributo"] == "dict":
+                        valor = None
+                        if chave in conteudo[self.meio_pagamento]:
+                            valor = conteudo[self.meio_pagamento][chave]
+                        setattr(self, chave, valor)
         except KeyError:
             raise ParametroInstalacaoInvalido(u"O atributo ou o tipo do atributo não foi encontrado nas configurações. Você esqueceu de inclui-lo em pagador.settings.MODULO_PARAMETROS_INSTALACAO?")
 
